@@ -128,7 +128,7 @@ def rigidBodySVDFun(mkrs, mkrList, args):
         N x 3 translation vector.
 
     """
-    
+
     # Get verbosity
     if 'verbose' in args:
         verbose = args['verbose']
@@ -178,7 +178,7 @@ def rigidBodySVDFun(mkrs, mkrList, args):
 
         if verbose:
             print('RMSE for rigid pose estimation (%d markers) for frame %d: %.5f mm. Max distance for %s: %.5f mm' % (Nv, i, RMSEi, mkrList[iMaxi], eMaxi))
-        
+
         # Insert data
         R[i,:,:] = Ri
         T[i,:] = Ti
@@ -192,8 +192,8 @@ def rigidBodySVDFun(mkrs, mkrList, args):
     info['eMax'] = eMax
     info['eMaxMarker'] = eMaxMarker
     return R, T, info
-    
-    
+
+
 def rigidBodySVDFun2(mkrs, mkrList, args):
     """Function for calculating the optimal roto-translation matrix from a rigid
     cluster of markers to laboratory reference frame. The computation, by using
@@ -230,13 +230,13 @@ def rigidBodySVDFun2(mkrs, mkrList, args):
         N x 3 translation vector.
 
     """
-    
+
     # Get verbosity
     if 'verbose' in args:
         verbose = args['verbose']
     else:
         verbose = True
-        
+
     # Get request for additional origin from trilat
     if 'useOriginFromTrilat' in args:
         useOriginFromTrilat = args['useOriginFromTrilat']
@@ -249,10 +249,10 @@ def rigidBodySVDFun2(mkrs, mkrList, args):
     # Create Nmarkers x 3 matrix for local coordinates
     mkrList_ = mkrList[:]
     x = np.array([np.asarray(mkrsLoc[m]) for m in mkrList])
-    
+
     # Check if trilat can actually be used
     useOriginFromTrilat = useOriginFromTrilat and len(mkrList) == 3
-    
+
     if useOriginFromTrilat:
         x = np.vstack([x, [0,0,0]])
         mkrList_.append(','.join(mkrList) + ' center')
@@ -267,7 +267,7 @@ def rigidBodySVDFun2(mkrs, mkrList, args):
     for i in range(0,Nf):
         # Create Nmarkers x 3 matrix for global coordinates
         y = np.array([mkrs[m][i,:].tolist() for m in mkrList])
-        
+
         if useOriginFromTrilat:
             p = np.array(y)
             r = [np.sqrt(np.sum(mkrsLoc[m]**2)) for m in mkrList]
@@ -300,7 +300,7 @@ def rigidBodySVDFun2(mkrs, mkrList, args):
 
         if verbose:
             print('RMSE for rigid pose estimation (%d markers) for frame %d: %.5f mm. Max distance for %s: %.5f mm' % (Nv, i, RMSEi, mkrList_[iMaxi], eMaxi))
-        
+
         # Insert data
         R[i,:,:] = Ri
         T[i,:] = Ti
@@ -803,8 +803,8 @@ def collinearNPointsStylusFun(P, args):
     tip = np.hstack((X,Y,Z))
 
     return tip
-    
-    
+
+
 def nonCollinear5PointsStylusFun(P, args, verbose=True):
     """Tip reconstruction function for 5 non-collinear points.
     The five markers are supposed to be on the same plane.
@@ -812,7 +812,7 @@ def nonCollinear5PointsStylusFun(P, args, verbose=True):
     - stylus markers adjusting based on a template and SVD;
     - trilateration by 2 couples of 3 markers, giving in-plane vector "u" and
     off-plane vector "v" (see ``trilateration()``);
-    - replace "v" position of the tip from trilateration by finding the versor 
+    - replace "v" position of the tip from trilateration by finding the versor
     normal to least-square plane through the 5 markers, and multiplying it by
     a known distance;
     - average the results of the 2 computed tip positions.
@@ -837,10 +837,10 @@ def nonCollinear5PointsStylusFun(P, args, verbose=True):
         as the radii of the sphere reconstructed around the markers.
         - 'offPlaneDist': off-plane distance (in *m*, see ``trilateration()``).
         It is used for the trilateration algorithm.
-        
+
     verbose : bool
         Indicates if to be verbose in printing messages.
-         
+
 
     Returns
     -------
@@ -848,8 +848,8 @@ def nonCollinear5PointsStylusFun(P, args, verbose=True):
         N x 3 array representing 3D coordinates of the reconstructed tip
         (in *mm*).
 
-    """        
-    
+    """
+
     # Assign convenient names to markers
     mkrNames = args['markers']
     nameP1 = mkrNames[0]
@@ -857,139 +857,146 @@ def nonCollinear5PointsStylusFun(P, args, verbose=True):
     nameP3 = mkrNames[2]
     nameP4 = mkrNames[3]
     nameP5 = mkrNames[4]
-    
+
     # Prepare common data for SVD
     dataSVD = {}
     dataSVD['mkrsLoc'] = args['pos']
     dataSVD['verbose'] = verbose
-    
+
+    infoFitting = {}
+
     if args['algoSVD'] == 1:
-    
+
         # Perform SVD for triangle of markers P1-P3-P5
-        print('Performing SVD with P1-P3-P5 ...')
+        if (verbose):
+            print('Performing SVD with P1-P3-P5 ...')
         mkrNames1 = [nameP1, nameP3, nameP5]
         R1, T1, info1 = rigidBodySVDFun(P, mkrNames1, dataSVD)
         RT1 = composeRotoTranslMatrix(R1, T1)
         Pf1 = changeMarkersReferenceFrame(args['pos'], RT1)
-        
+        infoFitting['SVD1'] = info1
+
         # Perform SVD for triangle of markers P2-P4-P5
-        print('Performing SVD with P2-P4-P5 ...')
+        if (verbose):
+            print('Performing SVD with P2-P4-P5 ...')
         mkrNames2 = [nameP2, nameP4, nameP5]
         R2, T2, info2 = rigidBodySVDFun(P, mkrNames2, dataSVD)
         RT2 = composeRotoTranslMatrix(R2, T2)
         Pf2 = changeMarkersReferenceFrame(args['pos'], RT2)
-        
+        infoFitting['SVD2'] = info1
+
         # Get markers and distances for trilaterations
         P1 = Pf1[nameP1]
         P2 = Pf2[nameP2]
         P3 = Pf1[nameP3]
         P4 = Pf2[nameP4]
         P5 = .5 * (Pf1[nameP5] + Pf2[nameP5])
-    
+
     elif args['algoSVD'] == 2:
-        
+
         # Perform SVD with all visible points
-        print('Performing SVD ...')
+        if (verbose):
+            print('Performing SVD ...')
         R, T, info = rigidBodySVDFun(P, mkrNames, dataSVD)
-#        try:
-#            R, T, info = rigidBodySVDFun(P, ['Wand:WN','Wand:WE','Wand:WM','Wand:WS'], dataSVD)
-#        except:
-#            R, T, info = rigidBodySVDFun(P, ['WN','WE','WM','WS'], dataSVD)
         RT = composeRotoTranslMatrix(R, T)
         Pf = changeMarkersReferenceFrame(args['pos'], RT)
-        
+        infoFitting['SVD'] = info
+
         # Get markers and distances for trilaterations
         P1 = Pf[nameP1]
         P2 = Pf[nameP2]
         P3 = Pf[nameP3]
         P4 = Pf[nameP4]
         P5 = Pf[nameP5]
-        
+
     if args['algoTrilat'] == 0:
-        
+
         tip = Pf['Tip']
-        
+
     elif args['algoTrilat'] == 1:
-                
+
         r = args['dist']
         r1 = r[nameP1]
         r2 = r[nameP2]
         r3 = r[nameP3]
         r4 = r[nameP4]
         r5 = r[nameP5]
-    
+
         # Perform trilaterations
-        print('Performing trilaterations ...')
+        if (verbose):
+            print('Performing trilaterations ...')
         Nf = P1.shape[0]
         u1 = np.zeros((Nf,3))
         u2 = np.zeros((Nf,3))
         v = np.zeros((Nf,3))
         for i in range(Nf):
-            
+
             # Perform trilateration with markers P1-P3-P5
             _u1, _v1 = trilateration(np.array([P1[i,:], P3[i,:], P5[i,:]]), np.array([r1, r3, r5]))
             #print np.linalg.norm(_v1)
             u1[i,:] = _u1
-            
+
             # Perform trilateration with markers P1-P3-P5
             _u2, _v2 = trilateration(np.array([P2[i,:], P4[i,:], P5[i,:]]), np.array([r2, r4, r5]))
             #print np.linalg.norm(_v2)
             u2[i,:] = _u2
-            
+
             # Find off-plane versor
             cplane = getNormalToLSPlane(np.array((P1[i,:], P2[i,:], P3[i,:], P4[i,:], P5[i,:])))
             _v = np.dot(np.cross(P3[i,:] - P2[i,:], P5[i,:] - P2[i,:]), cplane)
             v[i,:] = np.sign(_v) * args['offPlaneDist'] * cplane
-        
+
         # Find the 2 tips
-        print('Reconstructing 2 tips ...')
+        if (verbose):
+            print('Reconstructing 2 tips ...')
 #        tip1 = P1 + u1 + v
 #        tip2 = P2 + u2 + v
         tip1 = P1 + u1 + _v1
         tip2 = P2 + u2 + _v2
-        
+
         # Take the average of the two estimations for the tip position
-        print('Averaging 2 tips ...')
+        if (verbose):
+            print('Averaging 2 tips ...')
         tip = .5 * (tip1 + tip2)
-    
+
     print('Tip calculated')
-    return tip
-    
+    return tip, infoFitting
+
 
 def trilateration(p, r):
     """Perform trilateration algorithm to find the position of a point given
-    its distance from 3 points and the position of these 3 points in a 
+    its distance from 3 points and the position of these 3 points in a
     common reference frame.
     In particular, this function seeks the intersecting point of 3 spheres
-    defined by their centerpoint and radius. The intersection points can be 
-    calculated as i1 = p1+u1+v and i2 = p1+u1-v. This problem can have two, 
+    defined by their centerpoint and radius. The intersection points can be
+    calculated as i1 = p1+u1+v and i2 = p1+u1-v. This problem can have two,
     one or no solution; depending of the vector v (real, zero or non-existent).
-    In the case of no solution, i = p1+u1 can be taken as an estimate of the 
+    In the case of no solution, i = p1+u1 can be taken as an estimate of the
     solution.
 
     Parameters
     ----------
     p : np.ndarray
-        3 x 3 representing coordinates of the spheres centers, each row 
+        3 x 3 representing coordinates of the spheres centers, each row
         being a point.
-        
+
     r : np.ndarray
         Radii of the 3 spheres.
 
     Returns
     -------
     u1 : np.ndarray
-        3-elem array representing position of the intersecting point of three 
-        planes (the plane of the intersecting circle of sphere 1 and 2, 
-        the plane of the intersecting circle of sphere 1 and 3, the plane 
+        3-elem array representing position of the intersecting point of three
+        planes (the plane of the intersecting circle of sphere 1 and 2,
+        the plane of the intersecting circle of sphere 1 and 3, the plane
         containing the three center points) relative to the point c1.
         In the case of no solution, this point can be taken as an estimate of
         the solution.
-        
+
     v : np.ndarray
         Vector stretching from point u1 (in the plane of the three center
         points) to the two intersecting points.
-        If v = [0,0,0], there is only one solution. 
+        If v = [0,0,0], there is only one solution.
         In the case of no solution, v = [np.NaN, np.NaN, np.NaN].
 
     """
@@ -1003,7 +1010,7 @@ def trilateration(p, r):
     else:
         v = np.ones((3,)) * np.nan
     return u1, v
-    
+
 
 def getNormalToLSPlane(P):
     """Get normal versor of the plane best fitting N points in the least-square
@@ -1026,7 +1033,7 @@ def getNormalToLSPlane(P):
     n = np.linalg.solve(np.dot(P.T, P), np.dot(P.T, B))
     n = n / np.linalg.norm(n)
     return n.squeeze()
-        
+
 
 
 class Stylus:
@@ -1151,9 +1158,9 @@ def calculateStylusTipInCluster(stylus, markers, clusterMkrList, clusterArgs):
     tipLoc = changeMarkersReferenceFrame(markers, lRg)['Tip']
 
     return tipLoc
-    
-    
-    
+
+
+
 def thoraxPoseISB(mkrs):
     """Calculate roto-translation matrix from thorax (ISB conventions) to
     laboratory reference frame.
@@ -1206,8 +1213,8 @@ def thoraxPoseISB(mkrs):
 
     # Return data
     return R, Otho
-    
-    
+
+
 
 def pelvisPoseISB(mkrs, s='R'):
     """Calculate roto-translation matrix from pelvis (ISB conventions) to
@@ -1268,8 +1275,8 @@ def pelvisPoseISB(mkrs, s='R'):
 
     # Return data
     return R, Opel
-    
-    
+
+
 def pelvisPoseNoOneASI(mkrs, s='R'):
     """Calculate roto-translation matrix from pelvis (ISB conventions) to
     laboratory reference frame.
@@ -1661,8 +1668,8 @@ def calcaneusPoseWithClusterSVD(mkrs, clusterMkrList, args):
     R, T = calcaneusPose(mkrsSeg, s=args['side'])
 
     return R, T, mkrsSeg
-    
-    
+
+
 def humerusPose(mkrs, s='R'):
     """Calculate roto-translation matrix from humerus to
     laboratory reference frame.
@@ -1722,8 +1729,8 @@ def humerusPose(mkrs, s='R'):
 
     # Return data
     return R, Ohum
-    
-    
+
+
 def scapulaPose(mkrs, s='R'):
     """Calculate roto-translation matrix from scapula to
     laboratory reference frame.
@@ -1874,8 +1881,8 @@ def R2zxy(Rvect):
       xAngle=x2
     res = zAngle, xAngle, yAngle
     return res
-    
-    
+
+
 def R2yxyKS(Rvect):
     """Convert joint rotation matrix to YXY Euler sequence.
 
@@ -1897,10 +1904,10 @@ def R2yxyKS(Rvect):
     row3 = Rvect[6:9]
     R = np.matrix([row1,row2,row3]) # 3 x 3 joint rotation matrix
     ya, x, y = rot.R_to_euler_yxy(np.linalg.inv(R))
-    
+
     return y, x, ya
-    
-    
+
+
 def R2yxy(Rvect):
     """Convert joint rotation matrix to YXY Euler sequence.
 
@@ -1926,7 +1933,7 @@ def R2yxy(Rvect):
     x = np.arccos(R[1,1])
     y = np.arctan2(R[0,1], R[2,1])
     ya = np.arctan2(R[1,0], -R[1,2])
-    
+
     return y, x, ya
 
 
@@ -1941,8 +1948,9 @@ def getJointAngles(R1, R2, R2anglesFun=R2zxy, funInput='jointR', **kwargs):
     R2 : np.ndarray
         N x 3 x 3 rotation matrices from rigid body to global reference frame for body 2.
 
-    R2anglesFun : func
+    R2anglesFun : func, str
         Function converting from joint rotation matrix, or segment matrices, to angles (see ``R2zxy()``, ``ges()``).
+        When a string, it is an axis sequence (eg. 'xyz') for conversion to Euler angles.
 
     funInput : str
         Input type for R2anglesFun.
@@ -1968,20 +1976,28 @@ def getJointAngles(R1, R2, R2anglesFun=R2zxy, funInput='jointR', **kwargs):
         if len(Rjv.shape) == 1:
             Rjv = Rjv[None,:]
         angles = np.apply_along_axis(R2anglesFun, 1, Rjv, **kwargs)
-    else:
+    elif funInput == 'segmentsR':
         R1v = np.squeeze(np.reshape(inv2(R1),(N,9)))
         R2v = np.squeeze(np.reshape(inv2(R2),(N,9)))
         Rvect = np.hstack((R1v,R2v))
         if len(Rvect.shape) == 1:
             Rvect = Rvect[None,:]
         angles = np.apply_along_axis(R2anglesFun, 1, Rvect, **kwargs)
+    elif funInput == 'jointRMatrix':
+        Rj = dot3(inv2(R1), R2)
+        for i in range(N):
+            a1, q2, a3 = rot.R_to_euler(Rj[i,:,:], R2anglesFun)
+            angles[i,0] = a1
+            angles[i,1] = a2
+            angles[i,2] = a3
+
     # Correct for gimbal-lock
     angles[:,0] = correctGimbal(angles[:,0])
     angles[:,1] = correctGimbal(angles[:,1])
     angles[:,2] = correctGimbal(angles[:,2])
     return np.rad2deg(angles)
-    
-    
+
+
 def correctGimbal(angle):
     angle2 = angle[:]
     th = 1.5 * np.pi
@@ -2033,8 +2049,8 @@ def getJointTransl(R1, R2, O1, O2, T2translFun=None, **kwargs):
         Tvect = Tvect[None,:]
     transl = np.apply_along_axis(T2translFun, 1, Tvect, **kwargs)
     return transl
-    
-    
+
+
 def gesTranslFromSegment1(Tvect, **kwargs):
 
     Rvect = Tvect[0:18]
@@ -2050,8 +2066,8 @@ def gesTranslFromSegment1(Tvect, **kwargs):
     Tz = np.dot(v, z1)
 
     return Tx, Ty, Tz
-    
-    
+
+
 def lineFitSVD(points):
     # http://stackoverflow.com/questions/2298390/fitting-a-line-in-3d
     # Calculate center and versor
@@ -2067,8 +2083,8 @@ def lineFitSVD(points):
 #    print np.linalg.norm(points - centroid, axis=1)[:10]
 #    print proj[:10]
     return versor, center, other
-    
-    
+
+
 def planeFitSVD(points):
     # http://stackoverflow.com/questions/15959411/fit-points-to-a-plane-algorithms-how-to-iterpret-results
     # Calculate center and normal
