@@ -10,7 +10,7 @@ from .vtkh import *
 import numpy as np
 from scipy.optimize import minimize as spminimize
 from scipy.interpolate import RegularGridInterpolator
-
+from scipy import interpolate
   
     
 def calcLigaLength(ligaPath) :
@@ -40,7 +40,7 @@ def ligamentPathBlankevoort1991(pIns, edgeSpline):
     if np.dot(p1 - pem, pup) < 0:
         pe1, pe2 = pe2, pe1
     if np.dot(np.cross(p1 - pem, p2 - pem), pe2 - pe1) < 0:
-        print('Blankevoot: straight line not penetrating')
+#        print('Blankevoot: straight line not penetrating')
         pl = np.array((p1,p2))
 
 #    be = np.mean(pe, axis=0)
