@@ -327,7 +327,6 @@ def performSpineAnalysis2(
         'C7',
         'T12',
         'L2',
-#        'L3',
         'LL4',
         'RL4',
         'L4',
@@ -349,7 +348,6 @@ def performSpineAnalysis2(
         'g',
         'b',
         'b',
-#        'b',
         'b',
         'b',
         'b',
@@ -384,6 +382,8 @@ def performSpineAnalysis2(
             
     angleT12ToL4ToUpAxisSag = np.zeros((Nf,))
     angleT12ToL4ToUpAxisFro = np.zeros((Nf,))
+    angleT12ToSACRToUpAxisSag = np.zeros((Nf,))
+    angleT12ToSACRToUpAxisFro = np.zeros((Nf,))
     angleC7ToT12ToUpAxisSag = np.zeros((Nf,))
     angleC7ToT12ToUpAxisFro = np.zeros((Nf,))
 
@@ -404,6 +404,14 @@ def performSpineAnalysis2(
         vec = vec[::-1]
         angleT12ToL4ToUpAxisFro[i] = -np.rad2deg(np.arctan2(vec[1], vec[0])) + 90
         
+        vec = pointsDataSag[idxs['idx_T12'],:] - pointsDataSag[idxs['idx_SACR'],:]
+        vec = vec[::-1]
+        angleT12ToSACRToUpAxisSag[i] = -np.rad2deg(np.arctan2(vec[1], vec[0])) + 90
+        
+        vec = pointsDataFro[idxs['idx_T12'],:] - pointsDataFro[idxs['idx_SACR'],:]
+        vec = vec[::-1]
+        angleT12ToSACRToUpAxisFro[i] = -np.rad2deg(np.arctan2(vec[1], vec[0])) + 90
+        
         vec = pointsDataSag[idxs['idx_C7'],:] - pointsDataSag[idxs['idx_T12'],:]
         vec = vec[::-1]
         angleC7ToT12ToUpAxisSag[i] = -np.rad2deg(np.arctan2(vec[1], vec[0])) + 90
@@ -441,6 +449,8 @@ def performSpineAnalysis2(
     res['newMarkers'] = markersNew
     res['spineAngles']['T12ToL4ToUpAxisSag'] = angleT12ToL4ToUpAxisSag
     res['spineAngles']['T12ToL4ToUpAxisFro'] = angleT12ToL4ToUpAxisFro
+    res['spineAngles']['T12ToSACRToUpAxisSag'] = angleT12ToSACRToUpAxisSag
+    res['spineAngles']['T12ToSACRToUpAxisFro'] = angleT12ToSACRToUpAxisFro
     res['spineAngles']['C7ToT12ToUpAxisSag'] = angleC7ToT12ToUpAxisSag
     res['spineAngles']['C7ToT12ToUpAxisFro'] = angleC7ToT12ToUpAxisFro
     
